% "MCstrat" évalue le risque du ruine dans l'année par la méthode de
% Monte-Carlo avec stratification. "N" est le nombre de simulations
% demandées.
function MCstrat (N)
% Maintenant "nbruines" sera une quantité vectorielle, car on comptabilise
% séparément les ruines pour les différentes strates.
nbruines = zeros(1,3);
% "Nparstrate" contiendra le nombre de fois que les simulations sont
% tombées dans les différentes strates.
Nparstrate = zeros(1,3);
for i = 1:N
    % Noter la syntaxe pour récupérer les deux valeurs de retour de
    % "simulation2_pour_MCstrat".
    [ruine, strate] = simulation2_pour_MCstrat;
    % Il faut maintenir à jour "nbruines" et "Nparstrate".
    nbruines(strate) = nbruines(strate) + ruine;
    Nparstrate(strate) = Nparstrate(strate) + 1;
end
% Cette fois-ci il y a une estimateur de p différent pour chaque strate,
% avec pour chacun sa propre variance ; quantités que je considère dans le
% formalisme vectoriel de Matlab. Attention à bien distinguer la variance
% (estimée) "variance(i)" de la quantité dont p(i) estime l'espérance, et
% la variance "varest(i)" de l'estimateur p(i) en lui-même. Noter les
% syntaxe « ./ » et « .* » de Matlab qui effectuent une division, resp. une
% multiplication, case par case.
p = nbruines ./ Nparstrate;
variance = p .* (1-p);
varest = variance ./ Nparstrate;

% "vraietaillestrates" contient la probabilité véritable exacte des
% différentes strates, calculée de façon théorique. Je réintroduis les noms
% habituels des différents paramètres.
kappa = 1.2;
z0 = 10000;
tau = 1.;
T = 52;
vraietaillestrates = zeros(1,3);
vraietaillestrates(1) = exp(-T * tau * (400000/z0)^(-kappa));
% Notez comment on peut couper une longue ligne de code avec Matlab.
vraietaillestrates(2) = exp(-T * tau * (800000/z0)^(-kappa)) - ...
    vraietaillestrates(1);
vraietaillestrates(3) = 1 - vraietaillestrates(1) - vraietaillestrates(2);

disp(vraietaillestrates);

% On calcule maintenant l'estimateur global, ainsi que la variance associée
% (la variance *de l'estimateur*, je veux dire). Notez bien comment on
% calcule la cette variance à partir des variances des estimateurs de base
% : d'abord, il faut tenir compte la multiplication (déterministe) par
% l'entrée correspondante de "vraitaillestrates" ; puis utiliser que la
% variance de la somme est la somme des variances, étant donné qu'on somme
% des quantités *indépendantes*.
estimateurglobal = sum (vraietaillestrates .* p);
varestglobale = sum (vraietaillestrates.^2 .* varest);
erreurglobale = 1.96 * sqrt(varestglobale);

fprintf ('La probabilité de ruine est %.5f ± %.5f\n', ...
    estimateurglobal, erreurglobale);
end