function simulation1

% Paramètres

kappa = 1.2;
z0 = 10000;
tau = 1.;
a = 70000;
R0 = 1000000;

% "T" est l'amplitude temporelle de la simulation
T = 52;

% "dt" est le pas de temps pour la discrétisation. dt doit être
% suffisamment fin pour que l'évolution discrétisée soit une approximation
% “raisonnable” de la véritable évolution ; en particulier on voudrait
% qu'il ne puisse pratiquement jamais survenir deux sinistres dans le même
% pas de temps... Il n'y a pas vraiment de règle simple pour fixer la bonne
% valeur de dt ; il importe donc de garder à l'esprit que, si par malheur
% on a choisi une valeur de dt trop grande, l'erreur de discrétisation peut
% devenir prépondérante...
dt = 1/28.;
% "n" est le nombre de pas de temps
n = ceil(T/dt);
% "valeurs" est une liste stockant les valeurs de la réserve au cours du
% temps. Il faut une liste de taille (n+1) pour tenir compte aussi du temps
% 0.
valeurs = zeros(1,n+1);

% Valeur initiale de la réserve, à reporter également dans "liste".
R = R0;
valeurs(1) = R;

% "tt" est le numéro du pas de temps, correspondant au nombre de pas de
% temps écoulés depuis 0, doit t/dt.
for tt = 1:n,
    R = R + a*dt;
    if rand < tau * dt
        R = R - Pareto(z0, kappa);
    end
    % On remplit la case suivante de "valeurs". Noter le décalage d'indices
    % : le pas de temps tt correpond à l'indice (tt+1) de "valeurs",
    % puisque le temps 0 correspond à l'indice 1 de la liste.
    valeurs (tt + 1) = R;
end

% Affichage du graphique. Ne vous cassez pas trop la tête avec le
% paramétrage de la fonction "plot" de Matlab dans ce cours : c'est assez
% compliqué et ce n'est pas l'objet principal... Le premier argument de la
% fonction plot, à savoir « dt*(0:n) », est la liste des temps auxquels
% correspondent les différentes valeurs de "valeurs".
plot (dt*(0:n), valeurs);

end

