function simulation2

kappa = 1.2;
z0 = 10000;
tau = 1.;
a = 70000;
R0 = 1000000;
T = 52;

% Cette fois-ci il va falloir maintenir les valeurs de R *et* les temps
% correspondants, puisque les temps en question ne sont plus régulièrement
% espacés. La liste des temps est notée "listet". On initialise "valeurs"
% et "listet" avec les premières valeurs ; contrairement au cas précédent
% il faudra faire évoluer dynamiquement la taille de ces listes, dans la
% mesure où on ignore à priori leur taille finale. (Comme ce n'est pas une
% très bonne méthode de programmation, l'éditeur de Matlab émettra un
% warning à ce sujet, mais nous passerons outre ici).
t = 0;
R = R0;
listet = [t];
valeurs = [R];

% Puisqu'on ne sait pas à l'avance combien de pas de temps il va nous
% falloir, on a besoin d'une boucle "while".
while true
    % "attente" est le temps avant le prochain sinistre ; elle suit une loi
    % exponentielle de paramètre tau.
    attente = -log(rand) / tau;
    % Premier cas (normal) : le sinistre s'est produit avant la fin de
    % l'année.
    if (t + attente < T)
        % Notez qu'il faut alors ajouter *deux* points dans les listes : le
        % point juste avant le sinistre et le point juste après le sinistre
        % ! Sinon on ne verrait pas le décrochage sur la courbe... En
        % revanche, dans la mesure où l'évolution de la réserve est
        % linéaire en attendant le sinistre, il n'y a pas besoin de
        % préciser ce qui se passe pendant la phase d'“attente” : Matlab
        % tracera spontanément une droite.
        t = t + attente;
        % Juste avant le sinistre, il ne faut tenir compte que des primes
        % et pas du sinistre.
        R = R + attente * a;
        % Noter la syntaxe pour ajouter un terme à une liste en
        % l'allongeant au-delà de sa taille actuelle.
        listet (end + 1) = t;
        valeurs (end + 1) = R;
        % Juste après le sinistre, il faut maintenant tenir compte de la
        % somme déboursée par l'assureur.
        R = R - Pareto (z0, kappa);
        listet (end + 1) = t;
        valeurs (end + 1) = R;
        % Second cas (exceptionnel) : On a atteint la fin de l'année.
    else
        % Dans ce cas le moment du prochain sinistre ne nous intéresse pas
        % puisqu'il a lieu après T ; tout ce que nous voulons c'est
        % indiquer ce qui se passe jusqu'à T. On remplace donc attente par
        % (T-t).
        attente = T - t;
        % Cette fois-ci il n'y a pas de sinistre à prendre en compte, donc
        % il y a juste un point à ajouter dans les listes, correspondant
        % aux valeurs finales.
        R = R + attente * a;
        listet (end + 1) = T;
        valeurs (end + 1) = R;
        % Il faut maintenant quitter la boucle.
        break;
    end
end

%plot (listet, valeurs);

end
