% Voici une modification du preogramme "simulation2" qui évite d'avoir à
% gérer des listes de taille variable.
function simulation2_sanswarning

kappa = 1.2;
z0 = 10000;
tau = 1.;
a = 70000;
R0 = 1000000;
T = 52;

% La variable "alloue" indiquera la nombre de cases réservées pour stocker
% les résultats de nos calculs. Nous l'initialisons ici à 192.
alloue = 192;

% Sachant qu'il y aura en moyenne 52 sinistres, donc 106 entrées dans les
% listes "listet" et "valeurs", je prévois à priori, avec de la marge, 192
% entrées pour chacune d'elles. Ainsi je suis pratiquement certain que je
% n'aurai jamais à augmenter la taille de mes listes. Toutefois, pour que
% mon programme soit rigoureux, je tiendrai quand même compte plus loin du
% risque qu'on dépasse malgré tout cette valeur.
listet = zeros(1,alloue);
valeurs = zeros(1,alloue);
t = 0;
R = R0;
listet(1) = t;
valeurs(1) = R;

% J'ai besoin dans ce programme de savoir à quelle case de mes listes j'en
% suis. Cela sera indiqué par la variable "i".
i = 1;

while true
    attente = -log(rand) / tau;
    if (t + attente < T)
        t = t + attente;
        R = R + attente * a;
        listet (i+1) = t;
        valeurs (i+1) = R;
        R = R - Pareto (z0, kappa);
        listet (i+2) = t;
        valeurs (i+2) = R;
        % On met à jour la valeur de "i" pour la prochaine itération.
        i = i+2;
    else
        attente = T - t;
        R = R + attente * a;
        listet (i+1) = T;
        valeurs (i+1) = R;
        i = i+1;
        break;
    end
    % Si "i" est trop grand et qu'on risque de dépasser la taille de la
    % liste à la prochaine itération, il faut préparer une plus grande
    % allocation de mémoire (qu'on va ici doubler) et recopier les données
    % dans la mémoire augmentée.
    if i > alloue - 2
        nouvellelistet = zeros(1,2*alloue);
        nouvellevaleurs = zeros(1,2*alloue);
        nouvellelistet(1:alloue) = listet(1:alloue);
        nouvellevaleurs(1:alloue) = valeurs(1:alloue);
        listet = nouvellelistet;
        valeurs = nouvellevaleurs;
        % Penser à mettre à jour "alloue" pour la suite.
        alloue = 2*alloue;
    end
end

% Il ne faut plotter que les valeurs effectivement remplies : l'indice "i"
% nous dit jusqu'où celles-ci courent.
plot (listet(1:i), valeurs(1:i));

end